//
//  PRButtonCell.m
//  PurpleRain
//

#import "PRButtonCell.h"
#import "NSColorAdditions.h"


@implementation PRButtonCell

@synthesize mouseOver;

- (void)drawWithFrame:(NSRect)cellFrame inView:(NSView *)controlView
{
	// setup the rounded rectangle
	const CGFloat radius = 2.0;
	NSRect bounds = NSOffsetRect(cellFrame, 0.5, 0.5);
	bounds.size.width -= 1.0;
	bounds.size.height -= 1.0;
	NSBezierPath *path = [NSBezierPath bezierPathWithRoundedRect:bounds xRadius:radius yRadius:radius];

	// define the colors
	NSColor *start = [NSColor colorWithCalibratedRed:100.0/255.0 green:100.0/255.0 blue:115.0/255.0 alpha:1.0];
	NSColor *end = [NSColor colorWithCalibratedRed:40.0/255.0 green:40.0/255.0 blue:48.0/255.0 alpha:1.0];
	NSColor *border = [NSColor colorWithCalibratedRed:35.0/255.0 green:35.0/255.0 blue:42.0/255.0 alpha:1.0];
	
	if ([self isHighlighted]) {
		// draw darker when the mouse is down over the button
		const CGFloat darker = 0.2;
		end = [start changeBy:darker];
		start = [end changeBy:darker];
	} else if (self.mouseOver) {
		// draw lighter when the mouse hovers over the button
		const CGFloat lighter = -0.1;
		start = [start changeBy:lighter];
		end = [end changeBy:lighter];
		border = [border changeBy:lighter];
	}

	// create and draw the gradient
	NSGradient *grad = [[[NSGradient alloc] initWithStartingColor:start endingColor:end] autorelease];
	[grad drawInBezierPath:path angle:90.0];
	
	// draw the border
	[border set];
	[path stroke];
	
	// setup the title and draw it
	[NSGraphicsContext saveGraphicsState];
	NSMutableParagraphStyle *paraStyle = [[[NSParagraphStyle defaultParagraphStyle] mutableCopy] autorelease];
	[paraStyle setLineBreakMode:NSLineBreakByTruncatingTail];
	NSDictionary *titleAttrs = [NSDictionary dictionaryWithObjectsAndKeys:
							  [NSFont systemFontOfSize:11.0], NSFontAttributeName,
							  [NSColor whiteColor], NSForegroundColorAttributeName,
							  paraStyle, NSParagraphStyleAttributeName,
							  nil];
	NSMutableAttributedString *titleStr = [[[NSMutableAttributedString alloc] initWithString:[self title] attributes:titleAttrs] autorelease];
	[titleStr setAlignment:NSCenterTextAlignment range:NSMakeRange(0, [titleStr length])];
	NSRect titleRect = NSMakeRect(bounds.origin.x, 0.0, bounds.size.width, [titleStr size].height);
	titleRect.origin.y = (bounds.size.height - titleRect.size.height) / 2.0;
	[titleStr drawInRect:titleRect];
	[NSGraphicsContext restoreGraphicsState];
}

@end
